# Generated by Django 2.1.5 on 2019-01-09 16:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('site_parameters', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SiteSocialNetwork',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('slug', models.SlugField(max_length=120, unique=True)),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date Created')),
                ('date_modified', models.DateTimeField(auto_now=True, verbose_name='Last Updated')),
                ('order_in_list', models.PositiveIntegerField(default=0, verbose_name='Order in List')),
                ('service', models.CharField(help_text='The name of the service (e.g., Facebook, YouTube)', max_length=250, verbose_name='Site Name')),
                ('title_on_service', models.CharField(help_text='The page title WC uses at the service', max_length=250, verbose_name='Title of WorldChannel Page')),
                ('url', models.URLField(help_text="The URL of WC's page on the service.", max_length=250, verbose_name='URL')),
                ('svg_path', models.TextField(blank=True, help_text='You need to be superuser to edit this.', null=True, verbose_name='SVG Path')),
            ],
            options={
                'verbose_name': 'Social Media Site',
                'verbose_name_plural': 'Social Media Sites',
                'abstract': False,
            },
        ),
    ]
